==> skalibs-2.14.3.0_0.darwin_10.i386.tbz2: opt/local/include/skalibs/sysdeps.h <==
/* ISC license. */

#ifndef SYSDEPS_H
#define SYSDEPS_H

#undef SKALIBS_TARGET
#define SKALIBS_TARGET "i386-apple-darwin10.8.0"

#undef SKALIBS_HASCLOCKRT
#define SKALIBS_HASCLOCKRT

#undef SKALIBS_HASCLOCKMON
#define SKALIBS_HASCLOCKMON

#undef SKALIBS_HASCLOCKBOOT

#undef SKALIBS_HASPOSIXSPAWN
#define SKALIBS_HASPOSIXSPAWN

#undef SKALIBS_HASTIMER

#undef SKALIBS_HASPTHREAD
#define SKALIBS_HASPTHREAD

#undef SKALIBS_ENDIANNESS
#define SKALIBS_ENDIANNESS "little"

#undef SKALIBS_SIZEOFUSHORT
#define SKALIBS_SIZEOFUSHORT 2

#undef SKALIBS_SIZEOFUINT
#define SKALIBS_SIZEOFUINT 4

#undef SKALIBS_SIZEOFULONG
#define SKALIBS_SIZEOFULONG 4

#undef SKALIBS_HASUNSIGNEDSIZE
#undef SKALIBS_HASSIGNEDSIZE
#define SKALIBS_HASUNSIGNEDSIZE

#undef SKALIBS_SIZEOFSIZE
#define SKALIBS_SIZEOFSIZE 4

#undef SKALIBS_HASUNSIGNEDUID
#undef SKALIBS_HASSIGNEDUID
#define SKALIBS_HASUNSIGNEDUID

#undef SKALIBS_SIZEOFUID
#define SKALIBS_SIZEOFUID 4

#undef SKALIBS_HASUNSIGNEDGID
#undef SKALIBS_HASSIGNEDGID
#define SKALIBS_HASUNSIGNEDGID

#undef SKALIBS_SIZEOFGID
#define SKALIBS_SIZEOFGID 4

#undef SKALIBS_HASUNSIGNEDPID
#undef SKALIBS_HASSIGNEDPID
#define SKALIBS_HASSIGNEDPID

#undef SKALIBS_SIZEOFPID
#define SKALIBS_SIZEOFPID 4

#undef SKALIBS_HASUNSIGNEDTIME
#undef SKALIBS_HASSIGNEDTIME
#define SKALIBS_HASSIGNEDTIME

#undef SKALIBS_SIZEOFTIME
#define SKALIBS_SIZEOFTIME 4

#undef SKALIBS_HASUNSIGNEDDEV
#undef SKALIBS_HASSIGNEDDEV
#define SKALIBS_HASSIGNEDDEV

#undef SKALIBS_SIZEOFDEV
#define SKALIBS_SIZEOFDEV 4

#undef SKALIBS_HASUNSIGNEDINO
#undef SKALIBS_HASSIGNEDINO
#define SKALIBS_HASUNSIGNEDINO

#undef SKALIBS_SIZEOFINO
#define SKALIBS_SIZEOFINO 8

#undef SKALIBS_HASACCEPT4

#undef SKALIBS_HASCMSGCLOEXEC

#undef SKALIBS_HASDIRFD
#define SKALIBS_HASDIRFD

#undef SKALIBS_HASFDOPENDIR
#define SKALIBS_HASFDOPENDIR

#undef SKALIBS_HASEVENTFD

#undef SKALIBS_HASFLOCK
#define SKALIBS_HASFLOCK

#undef SKALIBS_HASGETPEEREID
#define SKALIBS_HASGETPEEREID

#undef SKALIBS_HASSOPEERCRED

#undef SKALIBS_HASGETPEERUCRED

#undef SKALIBS_HASIPV6
#define SKALIBS_HASIPV6

#undef SKALIBS_HASMSGDONTWAIT
#define SKALIBS_HASMSGDONTWAIT

#undef SKALIBS_HASOCLOEXEC
#define SKALIBS_HASOCLOEXEC

#undef SKALIBS_HASODIRECTORY

#undef SKALIBS_HASOPENAT
#define SKALIBS_HASOPENAT

#undef SKALIBS_HASLINKAT
#define SKALIBS_HASLINKAT

#undef SKALIBS_HASMEMMEM
#define SKALIBS_HASMEMMEM

#undef SKALIBS_HASPIPE2

#undef SKALIBS_HASPPOLL

#undef SKALIBS_HASREVOKE
#define SKALIBS_HASREVOKE

#undef SKALIBS_HASSENDFILE

#undef SKALIBS_HASSETGROUPS
#define SKALIBS_HASSETGROUPS

#undef SKALIBS_HASSETTIMEOFDAY
#define SKALIBS_HASSETTIMEOFDAY

#undef SKALIBS_HASSIGNALFD

#undef SKALIBS_HASSPLICE

#undef SKALIBS_HASSTATIM

#undef SKALIBS_HASSTATIMESPEC
#define SKALIBS_HASSTATIMESPEC

#undef SKALIBS_HASSTRCASESTR
#define SKALIBS_HASSTRCASESTR

#undef SKALIBS_HASSTRNLEN

#undef SKALIBS_HASUINT64T
#define SKALIBS_HASUINT64T

#undef SKALIBS_HASWAITID
#define SKALIBS_HASWAITID

#undef SKALIBS_HASFUTIMENS
#define SKALIBS_HASFUTIMENS

#undef SKALIBS_HASFUTIMES
#define SKALIBS_HASFUTIMES

#undef SKALIBS_HASARC4RANDOM
#define SKALIBS_HASARC4RANDOM

#undef SKALIBS_HASARC4RANDOM_ADDRANDOM
#define SKALIBS_HASARC4RANDOM_ADDRANDOM

#undef SKALIBS_HASITIMER
#define SKALIBS_HASITIMER

#undef SKALIBS_HASNAMESPACES

#undef SKALIBS_HASNSGETPARENT

#undef SKALIBS_HASEXPLICIT_BZERO

#undef SKALIBS_HASGETRANDOM

#undef SKALIBS_HASGRNDINSECURE

#undef SKALIBS_HASCHROOT
#define SKALIBS_HASCHROOT

#undef SKALIBS_HASCLONENEWPID

#undef SKALIBS_HASPOSIXSPAWNSETSID

#undef SKALIBS_HASPOSIXSPAWNSETSIDNP

#undef SKALIBS_HASPOSIXSPAWNCHDIR

#undef SKALIBS_HASPOSIXSPAWNCHDIRNP

#undef SKALIBS_HASDEVURANDOM
#define SKALIBS_HASDEVURANDOM

#undef SKALIBS_HASPOSIXSPAWNEARLYRETURN

#endif

==> skalibs-2.14.4.0_0.darwin_10.i386.tbz2: opt/local/include/skalibs/sysdeps.h <==
/* ISC license. */

#ifndef SYSDEPS_H
#define SYSDEPS_H

#undef SKALIBS_TARGET
#define SKALIBS_TARGET "i386-apple-darwin10.8.0"

#undef SKALIBS_HASCLOCKRT
#define SKALIBS_HASCLOCKRT

#undef SKALIBS_HASCLOCKMON
#define SKALIBS_HASCLOCKMON

#undef SKALIBS_HASCLOCKBOOT

#undef SKALIBS_HASPOSIXSPAWN
#define SKALIBS_HASPOSIXSPAWN

#undef SKALIBS_HASTIMER

#undef SKALIBS_HASPTHREAD
#define SKALIBS_HASPTHREAD

#undef SKALIBS_ENDIANNESS
#define SKALIBS_ENDIANNESS "little"

#undef SKALIBS_SIZEOFUSHORT
#define SKALIBS_SIZEOFUSHORT 2

#undef SKALIBS_SIZEOFUINT
#define SKALIBS_SIZEOFUINT 4

#undef SKALIBS_SIZEOFULONG
#define SKALIBS_SIZEOFULONG 4

#undef SKALIBS_HASUNSIGNEDSIZE
#undef SKALIBS_HASSIGNEDSIZE
#define SKALIBS_HASUNSIGNEDSIZE

#undef SKALIBS_SIZEOFSIZE
#define SKALIBS_SIZEOFSIZE 4

#undef SKALIBS_HASUNSIGNEDUID
#undef SKALIBS_HASSIGNEDUID
#define SKALIBS_HASUNSIGNEDUID

#undef SKALIBS_SIZEOFUID
#define SKALIBS_SIZEOFUID 4

#undef SKALIBS_HASUNSIGNEDGID
#undef SKALIBS_HASSIGNEDGID
#define SKALIBS_HASUNSIGNEDGID

#undef SKALIBS_SIZEOFGID
#define SKALIBS_SIZEOFGID 4

#undef SKALIBS_HASUNSIGNEDPID
#undef SKALIBS_HASSIGNEDPID
#define SKALIBS_HASSIGNEDPID

#undef SKALIBS_SIZEOFPID
#define SKALIBS_SIZEOFPID 4

#undef SKALIBS_HASUNSIGNEDTIME
#undef SKALIBS_HASSIGNEDTIME
#define SKALIBS_HASSIGNEDTIME

#undef SKALIBS_SIZEOFTIME
#define SKALIBS_SIZEOFTIME 4

#undef SKALIBS_HASUNSIGNEDDEV
#undef SKALIBS_HASSIGNEDDEV
#define SKALIBS_HASSIGNEDDEV

#undef SKALIBS_SIZEOFDEV
#define SKALIBS_SIZEOFDEV 4

#undef SKALIBS_HASUNSIGNEDINO
#undef SKALIBS_HASSIGNEDINO
#define SKALIBS_HASUNSIGNEDINO

#undef SKALIBS_SIZEOFINO
#define SKALIBS_SIZEOFINO 8

#undef SKALIBS_HASACCEPT4

#undef SKALIBS_HASCMSGCLOEXEC

#undef SKALIBS_HASDIRFD
#define SKALIBS_HASDIRFD

#undef SKALIBS_HASFDOPENDIR
#define SKALIBS_HASFDOPENDIR

#undef SKALIBS_HASEVENTFD

#undef SKALIBS_HASFLOCK
#define SKALIBS_HASFLOCK

#undef SKALIBS_HASGETPEEREID
#define SKALIBS_HASGETPEEREID

#undef SKALIBS_HASSOPEERCRED

#undef SKALIBS_HASGETPEERUCRED

#undef SKALIBS_HASIPV6
#define SKALIBS_HASIPV6

#undef SKALIBS_HASMSGDONTWAIT
#define SKALIBS_HASMSGDONTWAIT

#undef SKALIBS_HASOCLOEXEC
#define SKALIBS_HASOCLOEXEC

#undef SKALIBS_HASODIRECTORY

#undef SKALIBS_HASOPENAT
#define SKALIBS_HASOPENAT

#undef SKALIBS_HASLINKAT
#define SKALIBS_HASLINKAT

#undef SKALIBS_HASMEMMEM
#define SKALIBS_HASMEMMEM

#undef SKALIBS_HASPIPE2

#undef SKALIBS_HASPPOLL

#undef SKALIBS_HASREVOKE
#define SKALIBS_HASREVOKE

#undef SKALIBS_HASSENDFILE

#undef SKALIBS_HASSETGROUPS
#define SKALIBS_HASSETGROUPS

#undef SKALIBS_HASSETTIMEOFDAY
#define SKALIBS_HASSETTIMEOFDAY

#undef SKALIBS_HASSIGNALFD

#undef SKALIBS_HASSPLICE

#undef SKALIBS_HASSTATIM

#undef SKALIBS_HASSTATIMESPEC
#define SKALIBS_HASSTATIMESPEC

#undef SKALIBS_HASSTRCASESTR
#define SKALIBS_HASSTRCASESTR

#undef SKALIBS_HASSTRNLEN

#undef SKALIBS_HASUINT64T
#define SKALIBS_HASUINT64T

#undef SKALIBS_HASWAITID
#define SKALIBS_HASWAITID

#undef SKALIBS_HASFUTIMENS
#define SKALIBS_HASFUTIMENS

#undef SKALIBS_HASFUTIMES
#define SKALIBS_HASFUTIMES

#undef SKALIBS_HASARC4RANDOM
#define SKALIBS_HASARC4RANDOM

#undef SKALIBS_HASARC4RANDOM_ADDRANDOM
#define SKALIBS_HASARC4RANDOM_ADDRANDOM

#undef SKALIBS_HASITIMER
#define SKALIBS_HASITIMER

#undef SKALIBS_HASNAMESPACES

#undef SKALIBS_HASNSGETPARENT

#undef SKALIBS_HASEXPLICIT_BZERO

#undef SKALIBS_HASGETRANDOM

#undef SKALIBS_HASGRNDINSECURE

#undef SKALIBS_HASCHROOT
#define SKALIBS_HASCHROOT

#undef SKALIBS_HASCLONENEWPID

#undef SKALIBS_HASPOSIXSPAWNSETSID

#undef SKALIBS_HASPOSIXSPAWNSETSIDNP

#undef SKALIBS_HASPOSIXSPAWNCHDIR

#undef SKALIBS_HASPOSIXSPAWNCHDIRNP

#undef SKALIBS_HASGETAUXVAL

#undef SKALIBS_HASKERNPROCPATHNAME

#undef SKALIBS_HAS_NSGETEXECUTABLEPATH
#define SKALIBS_HAS_NSGETEXECUTABLEPATH

#undef SKALIBS_HASGETEXECNAME

#undef SKALIBS_HASDLADDR
#define SKALIBS_HASDLADDR

#undef SKALIBS_HASDEVURANDOM
#define SKALIBS_HASDEVURANDOM

#undef SKALIBS_HASPOSIXSPAWNEARLYRETURN

#undef SKALIBS_PROCSELFEXE

#endif
